@@ -182,7 +182,11 @@ sub compile_source_file {
   my $source_file = $compile_info->source_file;
   
   # Execute compile command
-  my $cbuilder = ExtUtils::CBuilder->new(quiet => 1);
+  my $cbuilder_config = {
+    cc => $config->cc,
+  };
+  
+  my $cbuilder = ExtUtils::CBuilder->new(quiet => 1, config => $cbuilder_config);
   
   my $output_file = $compile_info->output_file;
   
@@ -822,6 +826,12 @@ sub link {
     }
   }
   
+  # after_link_cbs
+  my $after_link_cbs = $config->after_link_cbs;
+  for my $after_link_cb (@$after_link_cbs) {
+    $after_link_cb->($link_info->config, $link_info);
+  }
+  
   return $output_file;
 }
 
@@ -840,62 +850,6 @@ sub create_link_info {
   
   my $output_type = $config->output_type;
   
-  my $lib_infos = [];
-  my $libs = $config->libs;
-  my $lib_dirs = $config->lib_dirs;
-  for my $lib (@$libs) {
-    my $lib_info;
-    
-    # Library is linked by file path
-    my $static;
-    my $lib_name;
-    my $is_abs;
-    if (ref $lib) {
-      $static = $lib->is_static;
-      $lib_name = $lib->name;
-      $is_abs = $lib->is_abs;
-      $lib_info = $lib;
-    }
-    else {
-      $lib_name = $lib;
-      $lib_info = SPVM::Builder::LibInfo->new(config => $config);
-      $lib_info->name($lib_name);
-    }
-    
-    if ($is_abs) {
-      my $found_lib_file;
-      for my $lib_dir (@$lib_dirs) {
-        $lib_dir =~ s|[\\/]$||;
-        
-        # Search dynamic library
-        unless ($static) {
-          my $dynamic_lib_file_base = "lib$lib_name.$Config{dlext}";
-          my $dynamic_lib_file = "$lib_dir/$dynamic_lib_file_base";
-          
-          if (-f $dynamic_lib_file) {
-            $found_lib_file = $dynamic_lib_file;
-            last;
-          }
-        }
-        
-        # Search static library
-        my $static_lib_file_base = "lib$lib_name.a";
-        my $static_lib_file = "$lib_dir/$static_lib_file_base";
-        if (-f $static_lib_file) {
-          $found_lib_file = $static_lib_file;
-          last;
-        }
-      }
-      
-      if (defined $found_lib_file) {
-        $lib_info->file = $found_lib_file;
-      }
-    }
-    
-    push @$lib_infos, $lib_info;
-  }
-  $config->libs($lib_infos);
-  
   # Output file
   unless (defined $output_file) {
     unless (defined $output_dir) {
