@@ -462,7 +462,7 @@ sub get_dynamic_lib_file_dist {
 
 sub create_default_config {
   
-  my $config = SPVM::Builder::Config->new_gnu99;
+  my $config = SPVM::Builder::Config->new_c99;
   
   return $config;
 }
