@@ -353,7 +353,7 @@ EOS
     my $native = $self->native;
     my $new_method;
     if ($native eq 'c') {
-      $new_method = 'new_gnu99';
+      $new_method = 'new_c99';
     }
     elsif ($native eq 'c++') {
       $new_method = 'new_cpp';
@@ -574,7 +574,7 @@ sub generate_native_config_file {
   my $native = $self->native;
   my $new_method;
   if ($native eq 'c') {
-    $new_method = 'new_gnu99';
+    $new_method = 'new_c99';
   }
   elsif ($native eq 'c++') {
     $new_method = 'new_cpp';
@@ -1079,7 +1079,7 @@ sub generate_basic_test_native_config_file {
   my $native = $self->native;
   my $new_method;
   if ($native eq 'c') {
-    $new_method = 'new_gnu99';
+    $new_method = 'new_c99';
   }
   elsif ($native eq 'c++') {
     $new_method = 'new_cpp';
